==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/StringMatch.java <==

package me.snowdrop.istio.api.networking.v1alpha3;

import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonDeserialize(using = me.snowdrop.istio.api.internal.ClassWithInterfaceFieldsDeserializer.class)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "matchType"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = true, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class StringMatch implements Serializable
{

    @JsonProperty("matchType")
    @JsonUnwrapped
    private me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType;
    private final static long serialVersionUID = 3747957407445592383L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public StringMatch() {
    }

    /**
     * 
     * @param matchType
     */
    public StringMatch(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType) {
        super();
        this.matchType = matchType;
    }

    @JsonProperty("matchType")
    public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType getMatchType() {
        return matchType;
    }

    @JsonProperty("matchType")
    public void setMatchType(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType) {
        this.matchType = matchType;
    }

    public interface MatchType extends Serializable
    {


    }

}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/StringMatch.java <==

package me.snowdrop.istio.api.networking.v1alpha3;

import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonDeserialize(using = me.snowdrop.istio.api.internal.ClassWithInterfaceFieldsDeserializer.class)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "matchType"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class StringMatch implements Serializable
{

    @JsonProperty("matchType")
    @JsonUnwrapped
    private me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType;
    private final static long serialVersionUID = 3747957407445592383L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public StringMatch() {
    }

    /**
     * 
     * @param matchType
     */
    public StringMatch(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType) {
        super();
        this.matchType = matchType;
    }

    @JsonProperty("matchType")
    public me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType getMatchType() {
        return matchType;
    }

    @JsonProperty("matchType")
    public void setMatchType(me.snowdrop.istio.api.networking.v1alpha3.StringMatch.MatchType matchType) {
        this.matchType = matchType;
    }

    public interface MatchType extends Serializable
    {


    }

}
